@@ -1,6 +1,6 @@
 package App::nauniq;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 1;
 # ABSTRACT: Non-adjacent uniq
@@ -17,7 +17,7 @@ App::nauniq - Non-adjacent uniq
 
 =head1 VERSION
 
-This document describes version 0.06 of App::nauniq (from Perl distribution App-nauniq), released on 2014-05-17.
+This document describes version 0.07 of App::nauniq (from Perl distribution App-nauniq), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -41,11 +41,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
